@@ -254,7 +254,7 @@ class Blob:
         blob_client.upload_blob(upload_object, blob_type="BlockBlob", overwrite=True)
 
 
-def _get_ingestion_service_bus_connection_string(api_inputs: ApiInputs):
+def _get_ingestion_service_bus_connection_string(api_inputs: ApiInputs, queue_type: str = 'DataIngestion'):
     """
     Get connection string specific to Data Ingestion Service Bus
 
@@ -269,9 +269,16 @@ def _get_ingestion_service_bus_connection_string(api_inputs: ApiInputs):
         Data Ingestion Service Bus connection string
     """
     headers = api_inputs.api_headers.default
+    
+    if not queue_type or queue_type == '':
+        queue_type = 'DataIngestion'
+    
+    params = {
+        'serviceBusType': queue_type
+    }
 
     url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/service-bus"
-    response = requests.request("GET", url, timeout=20, headers=headers)
+    response = requests.request("GET", url, timeout=20, headers=headers, params=params)
 
     if response.status_code != 200:
         logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
