@@ -19,7 +19,7 @@ import datetime
 import logging
 import uuid
 from .._utils._platform import _get_structure, Blob
-from .._utils._utils import (ApiInputs, _with_func_attrs, _column_name_cap, _work_order_schema, convert_bytes)
+from .._utils._utils import (ApiInputs, _with_func_attrs, _column_name_cap, _work_order_schema, convert_bytes, IngestionMode)
 from .._utils._constants import TAG_LEVEL
 from ..integration._utils import _timezone_offsets, _upsert_entities_affected_count, _adx_support, _timezone_dst_offsets
 
@@ -1153,7 +1153,7 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
 
 
 def upsert_data(data_frame, api_inputs: ApiInputs, table_name: str, key_columns: list,
-                is_slices_table=False):
+                is_slices_table=False, ingestion_mode: IngestionMode = 'Queue'):
     """Upsert data
 
     Upserts data to the `table_name` provided to the function call and uses the `key_columns` provided to determine the
@@ -1200,7 +1200,7 @@ def upsert_data(data_frame, api_inputs: ApiInputs, table_name: str, key_columns:
     # upload Blobs to folder
     upload_result = Blob.upload(api_inputs=api_inputs, data_frame=data_frame, name=table_name)
     json_payload = {"path": upload_result[0], "fileCount": upload_result[1], "operation": "upsert",
-                    "tableDef": table_structure, "keyColumns": key_columns}
+                    "tableDef": table_structure, "keyColumns": key_columns, 'ingestionMode': ingestion_mode}
 
     url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/data-operation?tableName={table_name}"
     logger.info("Sending request: POST %s", url)
